/*
 * Nomad Instrument Control Software
 *
 * Copyright 2011 Institut Laue-Langevin
 *
 * Licensed under the EUPL, Version 1.1 only (the "License");
 * You may not use this work except in compliance with the Licence.
 * You may obtain a copy of the Licence at:
 *
 * http://joinup.ec.europa.eu/software/page/eupl
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the Licence is distributed on an "AS IS" basis,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the Licence for the specific language governing permissions and
 * limitations under the Licence.
 */

#include <cmath>

#include "LEDParamController.h"
#include "controllers/common/family/Families.h"

using namespace std;

namespace stereo_daq {

const string LEDParamController::TYPE = "ledparam_controller";


/*
 * Constructor
 */
LEDParamController::LEDParamController(const string& name) :
	ExperimentController(name),Select(this),Set(this) {

	setFamily(family::ACQUISITION);

	// Init property


	m_Driver.init(this, "driver");

	m_StartActivated = false;

	registerFunction(TYPE);


}

LEDParamController::LEDParamController(const LEDParamController& controller) :
	ExperimentController(controller), Select(this),Set(this) {


	m_Driver.copy(controller.m_Driver);

	m_StartActivated = false;
}

/*
 * Destructor
 */
LEDParamController::~LEDParamController() {
	// Empty
}

void LEDParamController::postConfiguration() {

	registerProgression(m_Driver, &LEDParamController::updateProgression, this);


}



/*
 * updateProgression
 */
void LEDParamController::updateProgression() {
	// Calculate its own progression to manage retry case
	int32 progression = m_Driver->commandProgression();
	if (progression >= 100) {
		progression = 99;
	}
	commandProgression = progression;
}

/*
 * select channels
 */
void LEDParamController::select() {


}

void LEDParamController::set() {

}

}

