/*
 * Nomad Instrument Control Software
 *
 * Copyright 2011 Institut Laue-Langevin
 *
 * Licensed under the EUPL, Version 1.1 only (the "License");
 * You may not use this work except in compliance with the Licence.
 * You may obtain a copy of the Licence at:
 *
 * http://joinup.ec.europa.eu/software/page/eupl
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the Licence is distributed on an "AS IS" basis,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the Licence for the specific language governing permissions and
 * limitations under the Licence.
 */

#include "StereoElecDef.h"
#include "StereoElecState.h"
#include "StereoElecDriver.h"
#include "PerfectStereoElecDriver.h"
#include "RealStereoElecDriver.h"
#include "drivers/global/DriversCommands.h"

namespace stereo_elec {

const std::string StereoElecDriver::TYPE = "stereo_elec";

/*
 * Constructor
 */
StereoElecDriver::StereoElecDriver(const string& name):
	    DeviceDriver(name),acquisition::DPPAcquisitionCommon(name),acquisition::TimeGateCommon(name), acquisition::DetectorCommon(name)
{

		registerStates(new RealStereoElecDriver(this), new PerfectStereoElecDriver(this), new PerfectStereoElecDriver(this));

		triggermacaddress.init(this, SAVE, "triggermacaddress");
		triggeripaddress.init(this, SAVE, "triggeripaddress");
		nslot.init(this, NOSAVE, "nslot");
		nfeboard.init(this, SAVE, "nfeboard");
		nledboard.init(this, SAVE, "nledboard");
		boardtype.init(this, SAVE, "boardtype");
		boardmacaddress.init(this, SAVE, "boardmacaddress");
		boardipaddress.init(this, SAVE, "boardipaddress");
		namechannel0.init(this, SAVE, "namechannel0");
		namechannel1.init(this, SAVE, "namechannel1");
		namechannel2.init(this, SAVE, "namechannel2");
		namechannel3.init(this, SAVE, "namechannel3");
		namechannel4.init(this, SAVE, "namechannel4");
		namechannel5.init(this, SAVE, "namechannel5");
		namechannel6.init(this, SAVE, "namechannel6");
		namechannel7.init(this, SAVE, "namechannel7");


		/*
		 *  Init the device command list
		 */
		initCommand(driver::INIT_COMMAND);
		initCommand(driver::STATUS_COMMAND);
		initCommand(driver::START_COMMAND);
		initCommand(driver::READ_COMMAND);
		initCommand(driver::SYNCHRONIZE_READ_COMMAND);
		initCommand(driver::STOP_COMMAND);
		initCommand(driver::READ_INFOS_COMMAND);
		initCommand(DetectorCommon::CLEAR_COMMAND);
		initCommand(AcquisitionCommon::WRITE_PARAMETERS_COMMAND);


		registerFunction(STEREOELEC_FUNCTION);
		registerRefresher(boardtype,&StereoElecDriver::refreshBoardTypeProperty, this);

		nslot=NBSLOT;
		cout << "nslot= " << nslot() << endl;
		boardtype.resize(nslot());
		boardmacaddress.resize(nslot());
		boardipaddress.resize(nslot());
		namechannel0.resize(nslot());
		namechannel1.resize(nslot());
		namechannel2.resize(nslot());
		namechannel3.resize(nslot());
		namechannel4.resize(nslot());
		namechannel5.resize(nslot());
		namechannel6.resize(nslot());
		namechannel7.resize(nslot());
		nfeboard=0;
		nledboard=0;
}

/*
 * Destructor
 */
StereoElecDriver::~StereoElecDriver()
{
	// Empty
}
void StereoElecDriver::refreshBoardTypeProperty(int32 index, const string& value) throw (CannotSetValue) {

	cout << "refresh board type " << boardtype(index) << endl;
	if(boardtype(index)==FEBOARD && value!=FEBOARD) nfeboard=nfeboard()-1;
	if(boardtype(index)==LEDBOARD && value!=LEDBOARD) nledboard=nledboard()-1;
	if(boardtype(index)!=FEBOARD && value==FEBOARD) nfeboard=nfeboard()+1;
	if(boardtype(index)!=LEDBOARD && value==LEDBOARD) nledboard=nledboard()+1;

	if(value!=FEBOARD&&value!=LEDBOARD){
		boardmacaddress.set(index,"none");
		boardipaddress.set(index,"none");
		namechannel0.set(index,"none");
		namechannel1.set(index,"none");
		namechannel2.set(index,"none");
		namechannel3.set(index,"none");
		namechannel4.set(index,"none");
		namechannel5.set(index,"none");
		namechannel6.set(index,"none");
		namechannel7.set(index,"none");
	}


}
void StereoElecDriver::refreshNSlotProperty(int32 value) throw (CannotSetValue) {

}

/*
 * execute
 */
void StereoElecDriver::execute(const string& aCommand)
{
	if (aCommand == driver::INIT_COMMAND) {
		nfeboard=0;
		nledboard=0;
		for(int32 i=0;i<nslot();i++){
			cout << "init board type " <<boardtype(i) << endl;
			if(boardtype(i)=="FE") nfeboard=nfeboard()+1;
			else if(boardtype(i)=="LED") nledboard=nledboard()+1;
		}
	}
}



}
