/*
 * Nomad Instrument Control Software
 *
 * Copyright 2011 Institut Laue-Langevin
 *
 * Licensed under the EUPL, Version 1.1 only (the "License");
 * You may not use this work except in compliance with the Licence.
 * You may obtain a copy of the Licence at:
 *
 * http://joinup.ec.europa.eu/software/page/eupl
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the Licence is distributed on an "AS IS" basis,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the Licence for the specific language governing permissions and
 * limitations under the Licence.
 */

#ifndef STEREOELECDRIVER_H
#define STEREOELECDRIVER_H

#include <Driver.h>
#include "StereoElecDef.h"
#include "STDAQParams.h"
#include "controllers/common/acquisition/mode/DPPAcquisitionCommon.h"
#include "controllers/common/acquisition/gate/TimeGateCommon.h"
#include "controllers/common/acquisition/detector/DetectorCommon.h"

namespace stereo_elec {

/*!
 * \class StereoElecDriver
 * \brief Main class for the StereoElecDriver for the stereo electronics
 *
 * \par
 * Class for StereoElecDriver. Implements DeviceDriver methods.
 * \par
 * The StereoElecDriver device manages the global functionality of the stereo electronics.
 */

class StereoElecDriver : public virtual DeviceDriver,
						 public acquisition::DPPAcquisitionCommon,
						 public acquisition::TimeGateCommon,
						 public acquisition::DetectorCommon {

public:

	//! Driver type value
	static const std::string TYPE;

	/*!
	 * \brief Constructor
	 * \param[in] name the name of the device driver
	 */
	StereoElecDriver(const std::string& name);

	/*!
	 * \brief Destructor
	 */
	virtual ~StereoElecDriver();

	/*!
	 * \brief Method called for executing a command
	 *
	 * \param[in] command the command to apply on the controller
	 */
	void execute(const string& aCommand);


	virtual void refreshNSlotProperty(int32 value) throw (CannotSetValue);
	virtual void refreshBoardTypeProperty(int32 index,const std::string& value) throw (CannotSetValue);

	Property<std::string> triggermacaddress;
	Property<std::string> triggeripaddress;
	Property<int32> nslot;
	Property<int32> nfeboard;
	Property<int32> nledboard;
	DynamicProperty<std::string> boardtype;
	DynamicProperty<std::string> boardmacaddress;
	DynamicProperty<std::string> boardipaddress;
	DynamicProperty<std::string> namechannel0;
	DynamicProperty<std::string> namechannel1;
	DynamicProperty<std::string> namechannel2;
	DynamicProperty<std::string> namechannel3;
	DynamicProperty<std::string> namechannel4;
	DynamicProperty<std::string> namechannel5;
	DynamicProperty<std::string> namechannel6;
	DynamicProperty<std::string> namechannel7;


	STDAQParams DAQParams;
};

}
#endif //STEREOELECDRIVER_H
